@@ -5,14 +5,14 @@ our $AUTHORITY = 'cpan:GENE';
 
 use v5.36;
 
-our $VERSION = '0.0106';
+our $VERSION = '0.0200';
 
 use strictures 2;
 use List::SomeUtils qw(first_index);
 use MIDI::Drummer::Tiny ();
 use MIDI::RtMidi::ScorePlayer ();
 use Moo;
-use Types::Standard qw(ArrayRef Num);
+use Types::Standard qw(ArrayRef Num Maybe);
 use namespace::clean;
 
 
@@ -24,6 +24,20 @@ has rtc => (
 );
 
 
+has value => (
+    is      => 'rw',
+    isa     => Maybe[Num],
+    default => undef,
+);
+
+
+has trigger => (
+    is      => 'rw',
+    isa     => Maybe[Num],
+    default => undef,
+);
+
+
 has bars => (
     is  => 'rw',
     isa => Num,
@@ -55,7 +69,10 @@ sub _drum_parts ($self, $note) {
     return $part;
 }
 sub drums ($self, $device, $dt, $event) {
-    my ($ev, $chan, $note, $vel) = $event->@*;
+    my ($ev, $chan, $note, $val) = $event->@*;
+    return 0 if $self->trigger && $note != $self->trigger;
+    return 0 if $self->value && $val != $self->value;
+
     return 1 unless $ev eq 'note_on';
     my $part = $self->_drum_parts($note);
     my $d = MIDI::Drummer::Tiny->new(
@@ -87,7 +104,7 @@ MIDI::RtController::Filter::Drums - RtController drum filters
 
 =head1 VERSION
 
-version 0.0106
+version 0.0200
 
 =head1 SYNOPSIS
 
@@ -120,6 +137,28 @@ filter for the drums.
 The required L<MIDI::RtController> instance provided in the
 constructor.
 
+=head2 value
+
+  $value = $filter->value;
+  $filter->value($number);
+
+Return or set the MIDI event value. This is a generic setting that can
+be used by filters to set or retrieve state. This often a whole number
+between C<0> and C<127>, but can take any number.
+
+Default: C<undef>
+
+=head2 trigger
+
+  $trigger = $filter->trigger;
+  $filter->trigger($number);
+
+Return or set the trigger. This is a generic setting that
+can be used by filters to set or retrieve state. This often a whole
+number between C<0> and C<127>, but can take any number.
+
+Default: C<undef>
+
 =head2 bars
 
   $bars = $filter->bars;
@@ -157,6 +196,10 @@ not.
 
 Play the drums.
 
+If B<trigger> or B<value> is set, the filter checks those against the
+MIDI event C<note> or C<value>, respectively, to see if the filter
+should be applied.
+
 =head1 SEE ALSO
 
 The F<eg/*.pl> program(s) in this distribution
